/***************************************************************************
                          rlistboxitem.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

/****************************************************************************
** rlistboxitem.h 1998/09/06 A. Mustun RibbonSoft 
**
** Copyright (C) 1998 RibbonSoft.  All rights reserved.
**
*****************************************************************************/

#ifndef RLAYERLIST_H
#define RLAYERLIST_H

#include <qlistbox.h>

class RListBoxItem : public QListBoxItem
{
public:
  RListBoxItem(const QString& _text, const QPixmap _pixmap);
  ~RListBoxItem();

  virtual const QPixmap* pixmap() const { return &pm; }
    
protected:
  virtual void  paint(QPainter* _painter);
  virtual int   height(const QListBox* _listBox) const;
  virtual int   width(const QListBox* _listBox) const;

private:
  QPixmap pm;

};


#endif

// EOF



